@@ -76,10 +76,10 @@ QUERY__user_id_from_username = "SELECT id FROM jaaql__user WHERE email = :userna
 QUERY__user_totp_upd = "UPDATE jaaql__user SET last_totp = :last_totp WHERE id = :user_id"
 QUERY__user_ip_sel = "SELECT encrypted_address as address, first_use, most_recent_use FROM jaaql__my_ips"
 QUERY__user_ip_count = "SELECT COUNT(*) FROM jaaql__my_ips"
-QUERY__user_ip_ins = "INSERT INTO jaaql__user_ip (the_user, address_hash, encrypted_address) VALUES (:id, :address_hash, :ip_address) ON CONFLICT ON CONSTRAINT jaaql__user_ip_unq DO UPDATE SET most_recent_use = current_timestamp RETURNING most_recent_use <> first_use as existed, id"
+QUERY__user_ip_ins = "INSERT INTO jaaql__user_ip (the_user, encrypted_address) VALUES (:id, :ip_address) ON CONFLICT ON CONSTRAINT jaaql__user_ip_unq DO UPDATE SET most_recent_use = current_timestamp RETURNING most_recent_use <> first_use as existed, id"
 QUERY__user_password_ins = "INSERT INTO jaaql__user_password (the_user, password_hash) VALUES (:the_user, :password_hash)"
-QUERY__fetch_user_latest_password = "SELECT id, email, password_hash, enc_totp_iv as totp_iv, last_totp, is_public FROM jaaql__user_latest_password WHERE email = :username"
-QUERY__fetch_user_latest_credentials = "SELECT id, email, password_hash, enc_totp_iv as totp_iv, last_totp, is_public, address_hash, ip_id FROM jaaql__user_latest_credentials WHERE email = :username AND address_hash = :address_hash"
+QUERY__fetch_user_latest_password = "SELECT id, email, password_created, password_hash, enc_totp_iv as totp_iv, last_totp, is_public FROM jaaql__user_latest_password WHERE email = :username"
+QUERY__fetch_user_latest_credentials = "SELECT id, email, password_created, password_hash, enc_totp_iv as totp_iv, last_totp, is_public, encrypted_address, ip_id FROM jaaql__user_latest_credentials WHERE email = :username AND encrypted_address = :ip_address"
 QUERY__sign_up_insert = "INSERT INTO jaaql__sign_up (the_user, email_template, data_lookup_json, invite_code) VALUES (:the_user, :template, :data_lookup_json, :invite_code) RETURNING key_a as invite_key, key_b as invite_poll_key, invite_code as invite_code"
 QUERY__sign_up_count = "SELECT COUNT(*) as count FROM jaaql__sign_up WHERE the_user = :the_user AND (created + interval '24 hour') > current_timestamp"
 QUERY__reset_count = "SELECT COUNT(*) as count FROM jaaql__reset_password WHERE the_user = :the_user AND (created + interval '24 hour') > current_timestamp"
